﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using ERPLite.Common;
using System.IO;
using ERPLite.Areas.People.Models;
using ERPLite.Areas.DashBoard.Models;
using ERPLite.Areas.Customers.Models;
using ERPLite.Areas.Sales.Models;
using ERPLite.Areas.Finances.Models;
using ERPLite.Areas.Setup.Models;


namespace ERPLite
{
    public class ControllerBase : Controller
    {
        public UISession UISession
        {
            get
            {
                if (HttpContext.Session["UISession"] == null)
                    HttpContext.Session["UISession"] = new UISession();

                return (UISession)HttpContext.Session["UISession"];
            }
            set
            {
                HttpContext.Session["UISession"] = value;
            }
        }

     
        protected void SaveModelToSession(object model, string sessionKey)
        {
            this.HttpContext.Session[sessionKey] = model;
        }

        protected object ClearModel(object model, string sessionKey)
        {
            model = null;
            this.HttpContext.Session[sessionKey] = null;
            ModelState.Clear();
            return model;
        }

        protected T getModel<T>(T model, string sessionKey)
        {
            if (HttpContext.Session[sessionKey] == null)
            {
                if (model != null) model = default(T);
                model = (T)System.Activator.CreateInstance(typeof(T));
                return model;
            }
            else
                return (T)HttpContext.Session[sessionKey];
        }

        protected T getModel<T>(string sessionKey)
        {
            if (HttpContext.Session[sessionKey] == null)
            {
                //if (model != null) model = default(T);
                T model = (T)System.Activator.CreateInstance(typeof(T));
                return model;
            }
            else
                return (T)HttpContext.Session[sessionKey];
        }
         
      
        public static string RenderViewToString(ControllerContext context, string viewName, object model)
        {
            if (string.IsNullOrEmpty(viewName))
                viewName = context.RouteData.GetRequiredString("action");

            var viewData = new ViewDataDictionary(model);

            using (var sw = new StringWriter())
            {
                var viewResult = ViewEngines.Engines.FindPartialView(context, viewName);
                var viewContext = new ViewContext(context, viewResult.View, viewData, new TempDataDictionary(), sw);
                viewResult.View.Render(viewContext, sw);

                return sw.GetStringBuilder().ToString();
            }
        }

    

    }
}